==> haskell-isomorphism-class-0.1.1-85.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-isomorphism-class.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 isomorphism-class
version:              0.1.1
visibility:           public
id:                   isomorphism-class-0.1.1-1OnDLySkELaBMMH5G6Xhen
key:                  isomorphism-class-0.1.1-1OnDLySkELaBMMH5G6Xhen
license:              MIT
copyright:            (c) 2022 Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/isomorphism-class
synopsis:             Isomorphism typeclass solving the conversion problem
description:          Lawful typeclass for lossless conversion between types.
category:             Conversion
abi:                  081f485610d596a96290164a3602a771
exposed:              True
exposed-modules:      IsomorphismClass
hidden-modules:
    IsomorphismClass.Prelude IsomorphismClass.TextCompat.Array

import-dirs:          /usr/lib/ghc-9.6.6/site-local/isomorphism-class-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/isomorphism-class-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/isomorphism-class-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isomorphism-class
hs-libraries:         HSisomorphism-class-0.1.1-1OnDLySkELaBMMH5G6Xhen
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ text-2.0.2
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-isomorphism-class/html/isomorphism-class.haddock

haddock-html:         /usr/share/doc/haskell-isomorphism-class/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-isomorphism-class-0.1.1-86-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-isomorphism-class.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 isomorphism-class
version:              0.1.1
visibility:           public
id:                   isomorphism-class-0.1.1-JbG9Rrh2owUFvc258UYodK
key:                  isomorphism-class-0.1.1-JbG9Rrh2owUFvc258UYodK
license:              MIT
copyright:            (c) 2022 Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/isomorphism-class
synopsis:             Isomorphism typeclass solving the conversion problem
description:          Lawful typeclass for lossless conversion between types.
category:             Conversion
abi:                  47c00b4a09bab4760c01b2cbb972aa8a
exposed:              True
exposed-modules:      IsomorphismClass
hidden-modules:
    IsomorphismClass.Prelude IsomorphismClass.TextCompat.Array

import-dirs:          /usr/lib/ghc-9.6.6/site-local/isomorphism-class-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/isomorphism-class-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/isomorphism-class-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isomorphism-class
hs-libraries:         HSisomorphism-class-0.1.1-JbG9Rrh2owUFvc258UYodK
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi text-2.0.2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-isomorphism-class/html/isomorphism-class.haddock

haddock-html:         /usr/share/doc/haskell-isomorphism-class/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
